.. oHySEM documentation master file, created by Erik Alvarez

.. image:: /../img/Escudo.png
   :scale: 70%
   :align: left

\ **o**\ptimized \ **Hy**\brid in \ **S**\ystems for \ **E**\nergy and \ **M**\arket management

(**oHySEM**)

“*Simplicity and Transparency in Energy Systems Planning*”

**oHySEM** is an open-source model distributed as a Python library, designed to provide optimal planning, operation, and management strategies for hybrid renewable electricity-hydrogen systems. It supports both stand-alone and grid-connected systems in participating in electricity and hydrogen markets, ensuring the seamless integration of new assets and efficient system scheduling.

The model has been developed at the `Instituto de Investigación Tecnológica (IIT) <https://www.iit.comillas.edu/index.php.en>`_ of
the `Universidad Pontificia Comillas <https://www.comillas.edu/en/>`_.

Index
=====

.. toctree::
   :maxdepth: 2

   Introduction.rst
   InputData.rst
   MathematicalFormulation.rst
   Projects.rst